"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onEvent = void 0;
const child_process_1 = require("child_process");
const wait_port_1 = __importDefault(require("wait-port"));
async function onEvent(event) {
    const resourceProps = await extractResourceProperties(event);
    switch (event.RequestType) {
        case 'Create':
        case 'Update':
            waitForTemporal(resourceProps);
            createNamespace(resourceProps);
            return {
                PhysicalResourceId: resourceProps.resourcePhysicalId,
            };
        case 'Delete': {
            // FIXME: Deleting a namespace is not yet supported - https://github.com/temporalio/temporal/issues/1679
            return {
                PhysicalResourceId: resourceProps.resourcePhysicalId,
            };
        }
    }
}
exports.onEvent = onEvent;
async function extractResourceProperties(event) {
    const inputProps = event.ResourceProperties;
    if (!inputProps.TemporalHost)
        throw new Error('"TemporalHost" is required');
    if (!inputProps.NamespaceName)
        throw new Error('"NamespaceName" is required');
    const resourcePhysicalId = `${inputProps.TemporalHost}://${inputProps.NamespaceName}`;
    return {
        temporalHost: inputProps.TemporalHost,
        namespaceName: inputProps.NamespaceName,
        resourcePhysicalId,
    };
}
function waitForTemporal(resourceProps) {
    const [host, port] = resourceProps.temporalHost.split(':');
    (0, wait_port_1.default)({
        host: host,
        port: parseInt(port),
    });
}
function createNamespace(resourceProps) {
    try {
        execTctlTool(resourceProps, ['--namespace', resourceProps.namespaceName, 'namespace', 'register']);
    }
    catch (e) {
        if (e.stderr.includes('AlreadyExists')) {
            return;
        }
        console.error(`Failed to create namespace '${resourceProps.namespaceName}'`);
        console.error(e);
        process.exit(1);
    }
}
function execTctlTool(context, command) {
    const args = [];
    const env = {
        HOME: '/tmp',
    };
    args.push('--address', `${context.temporalHost}`);
    args.push('--auto_confirm');
    (0, child_process_1.execFileSync)('/opt/temporal/bin/tctl', [...args, ...command], {
        encoding: 'utf-8',
        env,
    });
}
//# sourceMappingURL=TemporalNamespaceHandler.js.map